changeset 12295:270256b6d0b8 v8.0.1027

patch 8.0.1027: more terminals can't handle requesting cursor mode commit https://github.com/vim/vim/commit/2db0ec4b2ec405aca4e642e0420ce703f94914a8 Author: Bram Moolenaar <Bram@vim.org> Date: Thu Aug 31 20:17:59 2017 +0200 patch 8.0.1027: more terminals can't handle requesting cursor mode Problem: More terminals can't handle requesting cursor mode. Solution: Recognize Putty. (Hirohito Higashi) Also include Xfce in the version check. (Dominique Pelle) Recognize Konsole.
author Christian Brabandt <cb@256bit.org>
date Thu, 31 Aug 2017 20:30:04 +0200
parents 19d0c366d1ee
children bd603ab3114f
files src/term.c src/version.c
diffstat 2 files changed, 16 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -770,6 +770,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1027,
+/**/
     1026,
 /**/
     1025,
--- a/src/term.c
+++ b/src/term.c
@@ -4562,10 +4562,21 @@ check_termcode(
 				&& STRNCMP(tp + extra - 2, "1;95;0c", 7) == 0)
 			    is_not_xterm = TRUE;
 #  endif
 			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0,
 			 * assuming any version number over 3000 is not an
 			 * xterm. */
-			if (col >= 3000)
+			if (col >= 2800)
+			    is_not_xterm = TRUE;
+
+			/* PuTTY sends 0;136;0 */
+			if (col == 136
+				&& STRNCMP(tp + extra - 2, "0;136;0c", 8) == 0)
+			    is_not_xterm = TRUE;
+
+			/* Konsole sends 0;115;0 */
+			if (col == 115
+				&& STRNCMP(tp + extra - 2, "0;115;0c", 8) == 0)
 			    is_not_xterm = TRUE;
 
 			/* Only request the cursor style if t_SH and t_RS are
@@ -4562,10 +4562,21 @@ check_termcode(
 			    is_not_xterm = TRUE;
 #  endif
-			/* Gnome Terminal.app sends 1;3801;0 or 1;4402;0,
-			 * assuming any version number over 3000 is not an
+			/* Gnome terminal sends 1;3801;0 or 1;4402;0.
+			 * xfce4-terminal sends 1;2802;0.
+			 * Assuming any version number over 2800 is not an
 			 * xterm. */